<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:d="http://docbook.org/ns/docbook"
  xmlns:m="http://www.w3.org/1998/Math/MathML"
  xmlns="http://www.w3.org/1999/xhtml"
  exclude-result-prefixes="d m"
  version="1.1">
  
  <xsl:import href="../Common/common.xsl"/>
  
  <xsl:variable name="topicLookup" select="document('topics.tid.xml', .)"/>
  
  <xsl:template name="user.webhelp.head.content">
    <xsl:param name="node"/>
    
    <xsl:copy-of select="$toggleDisplayScript"/>
    
    <xsl:if test="//m:math">
      <script type="text/x-mathjax-config">MathJax.Hub.Config({tex2jax: {inlineMath: [['$','$'], ['\\(','\\)']]}});</script>
      <script src="mathjax/MathJax.js?config=TeX-AMS-MML_HTMLorMML">
        <xsl:comment>Self closing tags disallowed!</xsl:comment>
      </script>
    </xsl:if>
  </xsl:template>
  
  <!-- No logo related parameter on offer, sigh! -->
  <xsl:template name="webhelpheader.logo">
    <a href="index.html">
      <img style='margin-right: 2px; height: 59px; padding-right: 25px; padding-top: 8px' align="right"
        src='{$webhelp.common.dir}images/hdmlogo.svg' alt="{$brandname} Documentation"/>
    </a>
  </xsl:template>
  
  <!-- copy mathml to output -->
  <xsl:template match="m:*">
    <xsl:element name="{local-name()}">
      <xsl:copy-of select="@*"/>
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>
  
  <xsl:template match="d:videodata">
    <video controls="controls" preload="auto">
      <xsl:attribute name="title">
        <xsl:value-of select="normalize-space(../../../d:title)"/>
      </xsl:attribute>
      
      <xsl:variable name="hdm_ImageFilename"> <!-- hdm_ prefix: do not mess with docbook! -->
        <xsl:call-template name="mediaobject.filename">
          <xsl:with-param name="object" select=".."/>
        </xsl:call-template>
      </xsl:variable>
      
      <source src="{$hdm_ImageFilename}" type='video/webm' />
      <source src="{$hdm_ImageFilename}.mp4" type='video/mp4'/>
      <xsl:text>Your Browser does not support the video tag</xsl:text>
    </video>
  </xsl:template>
  
  <!-- Modifying Docbooc's standard -->
  
  <xsl:template match="d:qandaset">
    <xsl:variable name="title" select="(d:blockinfo/d:title|d:info/d:title|d:title)[1]"/>
    <xsl:variable name="preamble" select="*[local-name(.) != 'title'                                           and local-name(.) != 'titleabbrev'                                           and local-name(.) != 'qandadiv'                                           and local-name(.) != 'qandaentry']"/>
    <xsl:variable name="toc">
      <xsl:call-template name="pi.dbhtml_toc"/>
    </xsl:variable>
    
    <xsl:variable name="toc.params">
      <xsl:call-template name="find.path.params">
        <xsl:with-param name="table" select="normalize-space($generate.toc)"/>
      </xsl:call-template>
    </xsl:variable>
    
    <div>
      <xsl:apply-templates select="." mode="common.html.attributes"/>
      <xsl:call-template name="id.attribute">
        <xsl:with-param name="conditional" select="0"/>
      </xsl:call-template>
      <xsl:apply-templates select="$title"/>
      <xsl:if test="not($title)">
        <!-- andhor is output on title if there is one -->
        <xsl:call-template name="anchor">
          <xsl:with-param name="conditional" select="0"/>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="((contains($toc.params, 'toc') and $toc != '0') or $toc = '1')                   and not(ancestor::d:answer and not($qanda.nested.in.toc=0))">
        <xsl:call-template name="process.qanda.toc"/>
      </xsl:if>
      <xsl:apply-templates select="$preamble"/>
      <xsl:call-template name="process.qandaset"/>
    </div>
    
    <xsl:variable name="qandaId" select="@xml:id"/>
    <xsl:variable name="tid" select="$topicLookup/map/entry[@id = $qandaId]/@tid"/>
    <div class="bbForum" data-tid="{$tid}">
      <p>
        <a target="_blank">
          <xsl:attribute name="href">
            <xsl:text>https://bb.mi.hdm-stuttgart.de/topic/</xsl:text>
            <xsl:value-of select="$tid"/>
          </xsl:attribute>
          <xsl:text>Create comment</xsl:text>
        </a>
      </p>
    </div>
  </xsl:template>
  
</xsl:stylesheet>
